/*!
 * @module browser-dtector
 * @description A Javascript library to detect browser, version and platform
 * @version 3.3.0
 * @link https://github.com/sibiraj-s/browser-dtector.git
 * @licence MIT License, https://opensource.org/licenses/MIT
 */

'use strict';

function _classCallCheck(instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
}
function _defineProperties(target, props) {
  for (var i = 0; i < props.length; i++) {
    var descriptor = props[i];
    descriptor.enumerable = descriptor.enumerable || false;
    descriptor.configurable = true;
    if ("value" in descriptor) descriptor.writable = true;
    Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor);
  }
}
function _createClass(Constructor, protoProps, staticProps) {
  if (protoProps) _defineProperties(Constructor.prototype, protoProps);
  if (staticProps) _defineProperties(Constructor, staticProps);
  Object.defineProperty(Constructor, "prototype", {
    writable: false
  });
  return Constructor;
}
function _toPrimitive(input, hint) {
  if (typeof input !== "object" || input === null) return input;
  var prim = input[Symbol.toPrimitive];
  if (prim !== undefined) {
    var res = prim.call(input, hint || "default");
    if (typeof res !== "object") return res;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return (hint === "string" ? String : Number)(input);
}
function _toPropertyKey(arg) {
  var key = _toPrimitive(arg, "string");
  return typeof key === "symbol" ? key : String(key);
}

var KnownBrowsers = {
  chrome: 'Google Chrome',
  brave: 'Brave',
  crios: 'Google Chrome',
  edge: 'Microsoft Edge',
  edg: 'Microsoft Edge',
  edgios: 'Microsoft Edge',
  fennec: 'Mozilla Firefox',
  jsdom: 'JsDOM',
  mozilla: 'Mozilla Firefox',
  fxios: 'Mozilla Firefox',
  msie: 'Microsoft Internet Explorer',
  opera: 'Opera',
  opios: 'Opera',
  opr: 'Opera',
  rv: 'Microsoft Internet Explorer',
  safari: 'Safari',
  samsungbrowser: 'Samsung Browser',
  electron: 'Electron'
};
var KnownPlatforms = {
  'android': 'Android',
  'androidTablet': 'Android Tablet',
  'cros': 'Chrome OS',
  'fennec': 'Android Tablet',
  'ipad': 'IPad',
  'iphone': 'IPhone',
  'jsdom': 'JsDOM',
  'linux': 'Linux',
  'mac': 'Macintosh',
  'tablet': 'Android Tablet',
  'win': 'Windows',
  'windows phone': 'Windows Phone',
  'xbox': 'Microsoft Xbox'
};

var toFixed = function toFixed(val) {
  var fixed = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : -1;
  var REG_EXP = new RegExp("^-?\\d+(?:.\\d{0,".concat(fixed, "})?"));
  var match = Number(val).toString().match(REG_EXP);
  return match ? match[0] : null;
};
var utils = {
  toFixed: toFixed
};

var version = "3.3.0";

var getNavigator = function getNavigator() {
  if (typeof window !== 'undefined') {
    return window.navigator;
  }
  return null;
};
var BrowserDetector = /*#__PURE__*/function () {
  function BrowserDetector(inputUA) {
    var _getNavigator;
    _classCallCheck(this, BrowserDetector);
    this.userAgent = inputUA || ((_getNavigator = getNavigator()) === null || _getNavigator === void 0 ? void 0 : _getNavigator.userAgent) || null;
  }
  _createClass(BrowserDetector, [{
    key: "parseUserAgent",
    value: function parseUserAgent(userAgent) {
      var _navigator$brave, _KnownBrowsers, _KnownPlatforms;
      var browserMatches = {};
      var uaFresh = userAgent || this.userAgent || '';

      // convert to lower case and treat tabs and multiple sapces as single space
      var ua = uaFresh.toLowerCase().replace(/\s\s+/g, ' ');
      var browserMatch = /(edge)\/([\w.]+)/.exec(ua) || /(edg)[/]([\w.]+)/.exec(ua) || /(opr)[/]([\w.]+)/.exec(ua) || /(fxios)[/]([\w.]+)/.exec(ua) || /(edgios)[/]([\w.]+)/.exec(ua) || /(jsdom)[/]([\w.]+)/.exec(ua) || /(samsungbrowser)[/]([\w.]+)/.exec(ua) || /(electron)[/]([\w.]+)/.exec(ua) || /(chrome)[/]([\w.]+)/.exec(ua) || /(crios)[/]([\w.]+)/.exec(ua) || /(opios)[/]([\w.]+)/.exec(ua) || /(version)(applewebkit)[/]([\w.]+).*(safari)[/]([\w.]+)/.exec(ua) || /(webkit)[/]([\w.]+).*(version)[/]([\w.]+).*(safari)[/]([\w.]+)/.exec(ua) || /(applewebkit)[/]([\w.]+).*(safari)[/]([\w.]+)/.exec(ua) || /(webkit)[/]([\w.]+)/.exec(ua) || /(opera)(?:.*version|)[/]([\w.]+)/.exec(ua) || /(msie) ([\w.]+)/.exec(ua) || /(fennec)[/]([\w.]+)/.exec(ua) || ua.indexOf('trident') >= 0 && /(rv)(?::| )([\w.]+)/.exec(ua) || ua.indexOf('compatible') < 0 && /(mozilla)(?:.*? rv:([\w.]+)|)/.exec(ua) || [];
      var platformMatch = /(ipad)/.exec(ua) || /(ipod)/.exec(ua) || /(iphone)/.exec(ua) || /(jsdom)/.exec(ua) || /(windows phone)/.exec(ua) || /(xbox)/.exec(ua) || /(win)/.exec(ua) || /(tablet)/.exec(ua) || /(android)/.test(ua) && /(mobile)/.test(ua) === false && ['androidTablet'] || /(android)/.exec(ua) || /(mac)/.exec(ua) || /(linux)/.exec(ua) || /(cros)/.exec(ua) || [];
      var name = browserMatch[5] || browserMatch[3] || browserMatch[1] || null;
      var platform = platformMatch[0] || null;
      var version = browserMatch[4] || browserMatch[2] || null;

      // brave browser doesn't expose itslef via useragent
      // but as chrome browser
      var navigator = getNavigator();
      if (name === 'chrome' && typeof (navigator === null || navigator === void 0 ? void 0 : (_navigator$brave = navigator.brave) === null || _navigator$brave === void 0 ? void 0 : _navigator$brave.isBrave) === 'function') {
        name = 'brave';
      }
      if (name) {
        browserMatches[name] = true;
      }
      if (platform) {
        browserMatches[platform] = true;
      }
      var isAndroid = Boolean(browserMatches.tablet || browserMatches.android || browserMatches.androidTablet);
      var isTablet = Boolean(browserMatches.ipad || browserMatches.tablet || browserMatches.androidTablet);
      var isMobile = Boolean(browserMatches.android || browserMatches.androidTablet || browserMatches.tablet || browserMatches.ipad || browserMatches.ipod || browserMatches.iphone || browserMatches['windows phone']);
      var isDesktop = Boolean(browserMatches.cros || browserMatches.mac || browserMatches.linux || browserMatches.win);
      var isWebkit = Boolean(browserMatches.brave || browserMatches.chrome || browserMatches.crios || browserMatches.opr || browserMatches.safari || browserMatches.edg || browserMatches.electron);
      var isIE = Boolean(browserMatches.msie || browserMatches.rv);
      var browserInfo = {
        name: (_KnownBrowsers = KnownBrowsers[name]) !== null && _KnownBrowsers !== void 0 ? _KnownBrowsers : null,
        platform: (_KnownPlatforms = KnownPlatforms[platform]) !== null && _KnownPlatforms !== void 0 ? _KnownPlatforms : null,
        userAgent: uaFresh,
        version: version,
        shortVersion: version ? utils.toFixed(parseFloat(version), 2) : null,
        isAndroid: isAndroid,
        isTablet: isTablet,
        isMobile: isMobile,
        isDesktop: isDesktop,
        isWebkit: isWebkit,
        isIE: isIE
      };
      return browserInfo;
    }
  }, {
    key: "getBrowserInfo",
    value: function getBrowserInfo() {
      var browserInfo = this.parseUserAgent();
      return {
        name: browserInfo.name,
        platform: browserInfo.platform,
        userAgent: browserInfo.userAgent,
        version: browserInfo.version,
        shortVersion: browserInfo.shortVersion
      };
    }
  }], [{
    key: "VERSION",
    get: function get() {
      return version;
    }
  }]);
  return BrowserDetector;
}();

module.exports = BrowserDetector;
//# sourceMappingURL=browser-dtector.js.map
